{% load staticfiles %}
<script src="{% static "fancybox/js/jquery.fancybox.pack.js" %}" type="text/javascript"></script>
<script type="text/javascript">
  jQuery(document).ready(function($) {
    $("a[class*=fancybox]").fancybox({type: 'ajax'});
  });
</script>
